@@ -20,6 +20,7 @@ from typing import Dict, Any, List, Optional
 from .utils.config import INTERFACES, INTERFACES_WITH_INDEX, BROWSER_OPTIONS, DEFAULT_TIMEOUT, KEYBOARD
 from .utils.functions import required_fields, is_valid_url, action_name
 from .utils.logger import logging
+from .utils.ai_controller import AIController
 from .utils.exceptions import ConfigFormatError, ConfigFileError, InterfaceError, BrowserError, LoopError, AttachError, \
     NavigateError, ScreenshotError, ScrollError, ActionError
 
@@ -150,16 +151,10 @@ class PyWebWizardBase:
         self.keepass_password = keepass_password
         self.keepass_db = None
         self.undetectable = self.config.get('undetectable')
-        self.ai_enabled = bool(openai_api_key)
+        self.ai_enabled = openai_api_key is not None
         if self.ai_enabled:
-            try:
-                from .utils.ai_controller import AIController
-                self.ai = AIController(openai_api_key, ai_model)
-                logging.info("AI enabled successfully")
-            except ImportError as e:
-                self.ai_enabled = False
-                logging.warning(f"Could not load AI module: {str(e)}")
-                logging.warning("AI functionality will be disabled")
+            self.ai = AIController(openai_api_key, ai_model)
+            logging.info("AI enabled successfully")
         if keepass_file and keepass_password:
             if os.path.isfile(keepass_file):
                 try:
@@ -180,7 +175,7 @@ class PyWebWizardBase:
                 action_name = attr._action_name
                 self.actions_map[action_name] = attr
 
-    async def invoke_ai(self, task_description: str) -> bool:
+    def invoke_ai(self, task_description: str) -> bool:
         """
         Executes a complex task using AI to determine the necessary actions.
 
@@ -192,9 +187,9 @@ class PyWebWizardBase:
             return False
 
         try:
-            current_page_info = self._html({})
+            current_page_info = self._html({'action': 'html'})
             logging.info(f"Analyzing task: {task_description}")
-            actions = await self.ai.analyze_task(task_description, current_page_info)
+            actions = self.ai.analyze_task(task_description, current_page_info)
 
             if not actions:
                 logging.warning("No actions were generated for the task")
@@ -693,17 +688,19 @@ class PyWebWizard(PyWebWizardBase):
     def __init__(self, spell_file: str = None, spell_book: list = None, headers: dict = None,
                  destruct_on_finish: bool = True, external_functions_mapping: dict = None,
                  keepass_file: str = None, keepass_password: str = None,
-                 openai_api_key: str = None, ai_model: str = "gpt-4"):
+                 undetectable: bool = False, openai_api_key: str = None, ai_model: str = "gpt-4"):
         """
         Initializes the PyWebWizard with a specific configuration file and optional headers.
 
         :param spell_file: Path to the Spell file.
+        :param spell_book: Path to the SpellBook file.
         :param headers: Optional dictionary of headers for web requests.
+        :param undetectable: If True, uses the undetectable Chrome driver.
         :param openai_api_key: Optional OpenAI API key for AI-powered automation.
         :param ai_model: AI model to use (default: gpt-4).
         """
-        super().__init__(spell_file, headers, destruct_on_finish, external_functions_mapping,
-                         keepass_file, keepass_password, openai_api_key, ai_model)
+        super().__init__(spell_file, spell_book, headers, destruct_on_finish, external_functions_mapping,
+                         keepass_file, keepass_password, undetectable, openai_api_key, ai_model)
 
     def get_actions(self):
         """
